==> nextcloud-30.0.13.tgz: nextcloud/apps/activity/l10n/ast.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Feed d'actividá personal pa: %s",
    "Your feed URL is invalid" : "La URL del feed ye inválida",
    "Activity feed for %1$s" : "Feed d'actividá pa %1$s",
    "Activity feed" : "Feed d'actividá",
    "Your settings have been updated." : "Anovóse la configuración.",
    "Settings have been updated." : "Anovóse la configuración.",
    "Recent activity" : "Actividá recién",
    "No activities" : "Nun hai actividá",
    "More activities" : "Más actividaes",
    "Daily activity summary for %s" : "Resume d'actividá diariu pa: %s",
    "All activities" : "Toles actividaes",
    "By others" : "Por otros",
    "By you" : "Por ti",
    "Activity at %s" : "Actividá en %s",
    "Hello %s" : "Hola, %s",
    "Hello %s," : "Hola, %s.",
    "There was some activity at %s" : "Hebo actividá en %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más"],
    "Mail" : "Corréu electrónicu",
    "Push" : "Push",
    "Activity" : "Actividá",
    "Notifications" : "Avisos",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite que les persones vean un rexistru de la so actividá, la de los sos ficheros y la d'otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta aplicación permite que les persones vean les aiciones rellacionaes colos sos ficheros y datos de Nextcloud.\n\t\tCada persona pue configurar les sos opciones d'actividá individual na configuración personal,\n\t\tpa escoyer l'actividá que s'habría unviar a los teléfonos móviles, per corréu electrónicu\n\t\to si s'unvia un resume diariu cada mañana.\n\t\tHai más información disponible na documentación de l'aplicación actividá-",
    "Send email" : "Unviar un corréu electrónicu",
    "Send push notification" : "Unviar un avisu push",
    "Activity notification configuration" : "Configuración de los avisos d'actividá",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "You need to set up your email address before you can receive notification emails." : "Tienes de configurar una direición de corréu electrónicu enantes de poder recibir mensaxes d'avisu.",
    "Send activity emails" : "Unviar correos electrónicos d'actividá",
    "As soon as possible" : "Namás que se pueda",
    "Hourly" : "Cada hora",
    "Daily" : "Caldía",
    "Weekly" : "Selmanalmente",
    "You commented" : "Comentesti",
    "Message deleted by author" : "L'autor desanició'l mensaxe",
    "Open {filename}" : "Abrir «{filename}»",
    "in {path}" : "en {path}",
    "Home" : "Aniciu",
    "Could not load activities" : "Nun se pudo cargar l'actividá",
    "Loading activities" : "Cargando l'actividá",
    "This stream will show events like additions, changes & shares" : "Esti fluxu va amosar eventos como amiestos, cambeos y comparticiones",
    "No activity yet" : " Entá nun hai actividá",
    "Loading more activities" : "Cargando más actividá",
    "No more activities." : "Nun hai más actividá.",
    "Could not enable RSS link" : "Nun se pudo activar l'enllaz RSS",
    "RSS link copied to clipboard" : "L'enllaz RSS copióse nel cartafueyu",
    "Could not copy the RSS link, please copy manually:" : "Nun se pudo copiar l'enllaz RSS, cópialu manualmente:",
    "Activity settings" : "Configuración de l'actividá",
    "Enable RSS feed" : "Activar el feed RSS",
    "RSS feed" : "Feed RSS",
    "Copy RSS feed link" : "Copiar l'enllaz del feed RSS",
    "Personal notification settings" : "Configuración d'avisos personales",
    "Unable to load the activity list" : "Nun ye posible cargar la llista d'actividá",
    "Choose for which activities you want to get an email or push notification." : "Escueyi pa qué actividaes quies recibir un corréu electrónicu o un avisu push.",
    "Choose for which activities you want to get a push notification." : "Escueyi pa qué actividaes quies recibir un avisu push.",
    "Notification" : "Avisu",
    "Enable notification emails" : "Activa los correos electrónicos d'avisu",
    "Daily activity summary" : "Resume d'actividá diariu",
    "Send daily activity summary in the morning" : "Unvia un resume d'actividá diariu pela mañana",
    "Default settings" : "Configuración predeterminada",
    "Configure the default notification settings for new accounts." : "Configura les opciones d'avisu predeterminaes pa les cuentes nueves.",
    "Unable to save the settings" : "Nun ye posible guardar la configuración",
    "No more events to load" : "Nun hai más eventos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.13.tgz: nextcloud/apps/activity/l10n/ast.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Feed d'actividá personal pa: %s",
    "Your feed URL is invalid" : "La URL del feed ye inválida",
    "Activity feed for %1$s" : "Feed d'actividá pa %1$s",
    "Activity feed" : "Feed d'actividá",
    "Your settings have been updated." : "Anovóse la configuración.",
    "Settings have been updated." : "Anovóse la configuración.",
    "Recent activity" : "Actividá recién",
    "No activities" : "Nun hai actividá",
    "More activities" : "Más actividaes",
    "Daily activity summary for %s" : "Resume d'actividá diariu pa: %s",
    "All activities" : "Toles actividaes",
    "By others" : "Por otros",
    "By you" : "Por ti",
    "Activity at %s" : "Actividá en %s",
    "Hello %s" : "Hola, %s",
    "Hello %s," : "Hola, %s.",
    "There was some activity at %s" : "Hebo actividá en %s",
    "_and %n more _::_and %n more _" : ["y %n más","y %n más"],
    "You can change the frequency of these emails or disable them in the <a href=\"%s\">settings</a>." : "Pues camudar la frecuencia d'estos mensaxes o desactivalos na <a href=\"%s\">configuración</a>.",
    "You can change the frequency of these emails or disable them in the settings: %s" : "Pues camudar la frecuencia d'estos mensaxes o desactivalos na configuración: %s",
    "Mail" : "Corréu electrónicu",
    "Push" : "Push",
    "Activity" : "Actividá",
    "Notifications" : "Avisos",
    "This application enables people to view a log of activities about them, their files or other data." : "Esta aplicación permite que les persones vean un rexistru de la so actividá, la de los sos ficheros y la d'otros datos.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Esta aplicación permite que les persones vean les aiciones rellacionaes colos sos ficheros y datos de Nextcloud.\n\t\tCada persona pue configurar les sos opciones d'actividá individual na configuración personal,\n\t\tpa escoyer l'actividá que s'habría unviar a los teléfonos móviles, per corréu electrónicu\n\t\to si s'unvia un resume diariu cada mañana.\n\t\tHai más información disponible na documentación de l'aplicación actividá-",
    "Send email" : "Unviar un corréu electrónicu",
    "Send push notification" : "Unviar un avisu push",
    "Activity notification configuration" : "Configuración de los avisos d'actividá",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "You need to set up your email address before you can receive notification emails." : "Tienes de configurar una direición de corréu electrónicu enantes de poder recibir mensaxes d'avisu.",
    "Send activity emails" : "Unviar correos electrónicos d'actividá",
    "As soon as possible" : "Namás que se pueda",
    "Hourly" : "Cada hora",
    "Daily" : "Caldía",
    "Weekly" : "Selmanalmente",
    "You commented" : "Comentesti",
    "Message deleted by author" : "L'autor desanició'l mensaxe",
    "Open {filename}" : "Abrir «{filename}»",
    "in {path}" : "en {path}",
    "Home" : "Aniciu",
    "Could not load activities" : "Nun se pudo cargar l'actividá",
    "Loading activities" : "Cargando l'actividá",
    "This stream will show events like additions, changes & shares" : "Esti fluxu va amosar eventos como amiestos, cambeos y comparticiones",
    "No activity yet" : " Entá nun hai actividá",
    "Loading more activities" : "Cargando más actividá",
    "No more activities." : "Nun hai más actividá.",
    "Could not enable RSS link" : "Nun se pudo activar l'enllaz RSS",
    "RSS link copied to clipboard" : "L'enllaz RSS copióse nel cartafueyu",
    "Could not copy the RSS link, please copy manually:" : "Nun se pudo copiar l'enllaz RSS, cópialu manualmente:",
    "Activity settings" : "Configuración de l'actividá",
    "Enable RSS feed" : "Activar el feed RSS",
    "RSS feed" : "Feed RSS",
    "Copy RSS feed link" : "Copiar l'enllaz del feed RSS",
    "Personal notification settings" : "Configuración d'avisos personales",
    "Unable to load the activity list" : "Nun ye posible cargar la llista d'actividá",
    "Choose for which activities you want to get an email or push notification." : "Escueyi pa qué actividaes quies recibir un corréu electrónicu o un avisu push.",
    "Choose for which activities you want to get a push notification." : "Escueyi pa qué actividaes quies recibir un avisu push.",
    "Notification" : "Avisu",
    "Enable notification emails" : "Activa los correos electrónicos d'avisu",
    "Daily activity summary" : "Resume d'actividá diariu",
    "Send daily activity summary in the morning" : "Unvia un resume d'actividá diariu pela mañana",
    "Default settings" : "Configuración predeterminada",
    "Configure the default notification settings for new accounts." : "Configura les opciones d'avisu predeterminaes pa les cuentes nueves.",
    "Unable to save the settings" : "Nun ye posible guardar la configuración",
    "No more events to load" : "Nun hai más eventos"
},
"nplurals=2; plural=(n != 1);");
